@@ -1,4 +1,5 @@
-Puppet::Type.type(:database).provide(:mysql) do
+require File.expand_path(File.join(File.dirname(__FILE__), '..', 'mysql'))
+Puppet::Type.type(:database).provide(:mysql, :parent => Puppet::Provider::Mysql) do
   desc 'Manages MySQL database.'
 
   defaultfor :kernel => 'Linux'
@@ -6,18 +7,6 @@ Puppet::Type.type(:database).provide(:mysql) do
   optional_commands :mysql      => 'mysql'
   optional_commands :mysqladmin => 'mysqladmin'
 
-  def self.defaults_file
-    if File.file?("#{Facter.value(:root_home)}/.my.cnf")
-      "--defaults-extra-file=#{Facter.value(:root_home)}/.my.cnf"
-    else
-      nil
-    end
-  end
-
-  def defaults_file
-    self.class.defaults_file
-  end
-
   def self.instances
     mysql([defaults_file, '-NBe', 'show databases'].compact).split("\n").collect do |name|
       new(:name => name)
