@@ -17,7 +17,7 @@ Puppet::Type.newtype(:mysql_grant) do
     # Sort the privileges array in order to ensure the comparision in the provider
     # self.instances method match.  Otherwise this causes it to keep resetting the
     # privileges.
-    self[:privileges] = Array(self[:privileges]).sort!
+    self[:privileges] = Array(self[:privileges]).map(&:upcase).uniq.reject{|k| k == 'GRANT' or k == 'GRANT OPTION'}.sort!
   end
 
   validate do
@@ -49,7 +49,7 @@ Puppet::Type.newtype(:mysql_grant) do
       value.delete("`")
     end
 
-    newvalues(/.*\..*/)
+    newvalues(/.*\..*/,/@/)
   end
 
   newproperty(:user) do
