@@ -8,6 +8,7 @@ describe 'mysql::server::backup' do
             'backupdir'          => '/tmp',
             'backuprotate'       => '25',
             'delete_before_dump' => true,
+            'execpath'           => '/usr/bin:/usr/sbin:/bin:/sbin:/opt/zimbra/bin',
         }
     }
     context 'standard conditions' do
@@ -18,7 +19,7 @@ describe 'mysql::server::backup' do
         )}
 
         it { should contain_mysql_grant('testuser@localhost/*.*').with(
-            :privileges => ["SELECT", "RELOAD", "LOCK TABLES", "SHOW VIEW"]
+            :privileges => ["SELECT", "RELOAD", "LOCK TABLES", "SHOW VIEW", "PROCESS"]
         )}
 
         it { should contain_cron('mysql-backup').with(
@@ -51,6 +52,10 @@ describe 'mysql::server::backup' do
             # MySQL counts from 0 I guess.
             should contain_file('mysqlbackup.sh').with_content(/.*ROTATE=24.*/)
         end
+
+        it 'should have a standard PATH' do
+            should contain_file('mysqlbackup.sh').with_content(%r{PATH=/usr/bin:/usr/sbin:/bin:/sbin:/opt/zimbra/bin})
+        end
     end
 
     context 'custom ownership and mode for backupdir' do
