@@ -2,16 +2,14 @@ require 'beaker-rspec'
 
 UNSUPPORTED_PLATFORMS = [ 'Windows', 'Solaris', 'AIX' ]
 
-unless ENV['RS_PROVISION'] == 'no'
+unless ENV['RS_PROVISION'] == 'no' or ENV['BEAKER_provision'] == 'no'
+  if hosts.first.is_pe?
+    install_pe
+  else
+    install_puppet
+  end
   hosts.each do |host|
-    # Install Puppet
-    if host.is_pe?
-      install_pe
-    else
-      install_package host, 'rubygems'
-      on host, 'gem install puppet --no-ri --no-rdoc'
-      on host, "mkdir -p #{host['distmoduledir']}"
-    end
+    on hosts, "mkdir -p #{host['distmoduledir']}"
   end
 end
 
@@ -31,18 +29,11 @@ RSpec.configure do |c|
       if fact('osfamily') == 'RedHat'
         version = fact("operatingsystemmajrelease")
         shell("yum localinstall -y http://yum.puppetlabs.com/puppetlabs-release-el-#{version}.noarch.rpm")
-        if version == '6'
-          shell("yum localinstall -y http://mirror.pnl.gov/epel/6/i386/epel-release-6-8.noarch.rpm")
-        elsif version == '5'
-          shell("yum localinstall -y http://mirrors.servercentral.net/fedora/epel/5/i386/epel-release-5-4.noarch.rpm")
-        else
-          puts "Sorry, this version is not supported."
-          exit
-        end
       end
 
-      shell("/bin/touch #{default['distmoduledir']}/hiera.yaml")
+      shell("/bin/touch #{default['puppetpath']}/hiera.yaml")
       shell('puppet module install puppetlabs-stdlib --version 3.2.0', { :acceptable_exit_codes => [0,1] })
+      on host, puppet('module','install','stahnma/epel'), { :acceptable_exit_codes => [0,1] }
     end
   end
 end
